package org.springblade.openinterface.dianxin.DataIntegration.service;

import org.springblade.community.accessrecord.entity.AccessRecord;
import org.springblade.core.tool.api.R;
import org.springblade.estate.feedback.entity.Feedback;
import org.springblade.homecare.alarmlist.entity.Alarm;
import org.springblade.jobs.reportjob.entity.ReportJob;
import org.springblade.smartapplication.carenterrecord.entity.CarEnterRecord;
import org.springblade.smartapplication.caroutrecord.entity.CarOutRecord;
import org.springblade.smartapplication.temperaturerecord.entity.TemperatureRecord;

import java.util.List;
import java.util.Map;


/**
 * @author lidexi
 * @date 2021/7/16 10:48
 * 业务推送数据接口层
 */
public interface IBussinessDataPushService {

	/**
	 * 推送物业报修记录到数据融通
	 * @param reportJob
	 * @return
	 */
	 R pushEstateRepair(ReportJob reportJob);

	/**
	 * 推送投诉建议记录到数据融通
	 * @param feedback
	 * @return
	 */
	 R pushAdvice(Feedback feedback);

	/**
	 * 推送人员出入记录到数据融通
	 * @param accessRecord
	 * @return
	 */
	 R pushUserRecord(AccessRecord accessRecord);

	/**
	 * 推送车辆进出记录到数据融通
	 * @param carEnterRecords
	 * @param carOutRecords
	 * @return
	 */
	 R pushCarRecord(List<CarEnterRecord> carEnterRecords, List<CarOutRecord> carOutRecords);

	/**
	 * 推送人脸抓拍记录到数据融通
	 * @param accessRecord
	 * @return
	 */
	 R pushFaceCatch(AccessRecord accessRecord);

	/**
	 * 推送烟感告警记录到数据融通
	 * @param alarm
	 * @return
	 */
	 R pushSmokeAlarm(Alarm alarm);

	/**
	 * 推送燃气告警记录到数据融通
	 * @param alarm
	 * @return
	 */
	 R pushGasAlarm(Alarm alarm);



}
